@@ -15,8 +15,9 @@ class Authenticator():
         print("public key",self.public_key)
         try:
             self.data = jwt.decode(token, public_key,algorithms=["RS256"],audience="justwicks")
-            print(self.data)
-            self.validate_telegram_id()
+            self.auth = True
+            # print(self.data)
+            # self.validate_telegram_id()
         except jwt.exceptions.DecodeError as err:
            self.custom_exception_handler(err)
 
